@@ -1,10 +1,11 @@
-# Copyright (c) 2019, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 #
 # Author: Enthought, Inc.
@@ -15,4 +16,4 @@
 # Import the toolkit specific version.
 from pyface.toolkit import toolkit_object
 
-ComboField = toolkit_object('fields.combo_field:ComboField')
+ComboField = toolkit_object("fields.combo_field:ComboField")
