@@ -1,24 +1,20 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ The implementation of a dialog that displays a message. """
 
 
-
-
 # Convenience functions.
-def information(parent, message, title='Information',
-                detail='', informative=''):
+def information(
+    parent, message, title="Information", detail="", informative=""
+):
     """ Convenience method to show an information message dialog.
 
     Parameters
@@ -37,13 +33,17 @@ def information(parent, message, title='Information',
 
     """
     dialog = MessageDialog(
-        parent=parent, message=message, title=title,
-        severity='information', detail=detail, informative=informative
+        parent=parent,
+        message=message,
+        title=title,
+        severity="information",
+        detail=detail,
+        informative=informative,
     )
     dialog.open()
 
 
-def warning(parent, message, title='Warning', detail='', informative=''):
+def warning(parent, message, title="Warning", detail="", informative=""):
     """ Convenience function to show a warning message dialog.
 
     Parameters
@@ -62,13 +62,17 @@ def warning(parent, message, title='Warning', detail='', informative=''):
 
     """
     dialog = MessageDialog(
-        parent=parent, message=message, title=title,
-        severity='warning', detail=detail, informative=informative
+        parent=parent,
+        message=message,
+        title=title,
+        severity="warning",
+        detail=detail,
+        informative=informative,
     )
     dialog.open()
 
 
-def error(parent, message, title='Error', detail='', informative=''):
+def error(parent, message, title="Error", detail="", informative=""):
     """ Convenience function to show an error message dialog.
 
     Parameters
@@ -87,14 +91,17 @@ def error(parent, message, title='Error', detail='', informative=''):
 
     """
     dialog = MessageDialog(
-        parent=parent, message=message, title=title, severity='error',
-        detail=detail, informative=informative
+        parent=parent,
+        message=message,
+        title=title,
+        severity="error",
+        detail=detail,
+        informative=informative,
     )
     dialog.open()
 
 
 # Import the toolkit specific version.
 from .toolkit import toolkit_object
-MessageDialog = toolkit_object('message_dialog:MessageDialog')
 
-#### EOF ######################################################################
+MessageDialog = toolkit_object("message_dialog:MessageDialog")
