@@ -1,10 +1,11 @@
-# Copyright (c) 2017, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
 # Note: The MultiToolbarWindow is currently wx-specific
@@ -13,4 +14,5 @@
 
 
 from .toolkit import toolkit_object
-MultiToolbarWindow = toolkit_object('multi_toolbar_window:MultiToolbarWindow')
+
+MultiToolbarWindow = toolkit_object("multi_toolbar_window:MultiToolbarWindow")
