@@ -1,15 +1,14 @@
-# Copyright (c) 2010-18, Enthought, Inc.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
-from __future__ import absolute_import
 
-# Local imports.
 from .advanced_editor_area_pane import AdvancedEditorAreaPane
 from .split_editor_area_pane import SplitEditorAreaPane
 from .dock_pane import DockPane
@@ -24,8 +23,14 @@ from .i_editor_area_pane import IEditorAreaPane
 from .i_task_pane import ITaskPane
 from .task import Task
 from .tasks_application import TasksApplication, TaskFactory
-from .task_layout import TaskLayout, PaneItem, Tabbed, Splitter, HSplitter, \
-    VSplitter
+from .task_layout import (
+    TaskLayout,
+    PaneItem,
+    Tabbed,
+    Splitter,
+    HSplitter,
+    VSplitter,
+)
 from .task_pane import TaskPane
 from .task_window import TaskWindow
 from .task_window_layout import TaskWindowLayout
