@@ -1,14 +1,35 @@
-# Standard library imports.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 import logging
 
-# Enthought library imports.
+
 from pyface.action.api import MenuBarManager, StatusBarManager, ToolBarManager
 from pyface.api import ApplicationWindow
-from traits.api import Bool, Callable, HasTraits, HasStrictTraits, Instance, \
-    List, Property, Unicode, Vetoable, on_trait_change
+from traits.api import (
+    Bool,
+    Callable,
+    HasTraits,
+    HasStrictTraits,
+    Instance,
+    List,
+    Property,
+    Str,
+    Vetoable,
+    on_trait_change,
+)
 
-# Local imports.
-from pyface.tasks.action.task_action_manager_builder import TaskActionManagerBuilder
+
+from pyface.tasks.action.task_action_manager_builder import (
+    TaskActionManagerBuilder,
+)
 from pyface.tasks.i_dock_pane import IDockPane
 from pyface.tasks.i_task_pane import ITaskPane
 from pyface.tasks.task import Task, TaskLayout
@@ -26,12 +47,12 @@ class TaskWindow(ApplicationWindow):
     its tasks.
     """
 
-    #### IWindow interface ####################################################
+    # IWindow interface ----------------------------------------------------
 
     # Unless a title is specifically assigned, delegate to the active task.
-    title = Property(Unicode, depends_on=['active_task.name', '_title'])
+    title = Property(Str, depends_on=["active_task.name", "_title"])
 
-    #### TaskWindow interface ################################################
+    # TaskWindow interface ------------------------------------------------
 
     # The pane (central or dock) in the active task that currently has focus.
     active_pane = Instance(ITaskPane)
@@ -56,16 +77,16 @@ class TaskWindow(ApplicationWindow):
     # the translation process, although this is not usually necessary.
     action_manager_builder_factory = Callable(TaskActionManagerBuilder)
 
-    #### Protected traits #####################################################
+    # Protected traits -----------------------------------------------------
 
-    _active_state = Instance('pyface.tasks.task_window.TaskState')
-    _states = List(Instance('pyface.tasks.task_window.TaskState'))
-    _title = Unicode
+    _active_state = Instance("pyface.tasks.task_window.TaskState")
+    _states = List(Instance("pyface.tasks.task_window.TaskState"))
+    _title = Str()
     _window_backend = Instance(TaskWindowBackend)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'Widget' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def destroy(self):
         """ Overridden to ensure that all task panes are cleanly destroyed.
@@ -80,9 +101,9 @@ class TaskWindow(ApplicationWindow):
             self._destroy_state(state)
         super(TaskWindow, self).destroy()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'Window' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def open(self):
         """ Opens the window.
@@ -104,34 +125,20 @@ class TaskWindow(ApplicationWindow):
             self.show(True)
             self.opened = self
 
-        return self.control is not None
+        return self.control is not None and not event.veto
 
-    def close(self):
-        """ Closes the window.
-
-        Overriden to make the 'closing' event vetoable. Returns whether the
-        window was closed.
-        """
-        if self.control is not None:
-            self.closing = event = Vetoable()
-            if not event.veto:
-                self.destroy()
-                self.closed = self
-
-        return self.control is None
-
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IApplicationWindow' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_contents(self, parent):
         """ Delegate to the TaskWindowBackend.
         """
         return self._window_backend.create_contents(parent)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'TaskWindow' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def activate_task(self, task):
         """ Activates a task that has already been added to the window.
@@ -155,15 +162,19 @@ class TaskWindow(ApplicationWindow):
             self._active_state = state
             task.activated()
         elif not state:
-            logger.warn("Cannot activate task %r: task does not belong to the "
-                        "window." % task)
+            logger.warn(
+                "Cannot activate task %r: task does not belong to the "
+                "window." % task
+            )
 
     def add_task(self, task):
         """ Adds a task to the window. The task is not activated.
         """
         if task.window is not None:
-            logger.error("Cannot add task %r: task has already been added "
-                         "to a window!" % task)
+            logger.error(
+                "Cannot add task %r: task has already been added "
+                "to a window!" % task
+            )
             return
 
         task.window = self
@@ -209,8 +220,10 @@ class TaskWindow(ApplicationWindow):
             self._destroy_state(state)
             self._states.remove(state)
         else:
-            logger.warn("Cannot remove task %r: task does not belong to the "
-                        "window." % task)
+            logger.warn(
+                "Cannot remove task %r: task does not belong to the "
+                "window." % task
+            )
 
     def focus_next_pane(self):
         """ Shifts focus to the "next" pane, taking into account the active pane
@@ -264,7 +277,7 @@ class TaskWindow(ApplicationWindow):
         state = self._get_state(id)
         return state.task if state else None
 
-    #### Methods for saving and restoring the layout ##########################
+    # Methods for saving and restoring the layout -------------------------#
 
     def get_layout(self):
         """ Returns a TaskLayout (for the active task) that reflects the state
@@ -290,8 +303,9 @@ class TaskWindow(ApplicationWindow):
     def get_window_layout(self):
         """ Returns a TaskWindowLayout for the current state of the window.
         """
-        result = TaskWindowLayout(position=self.position, size=self.size,
-                                  size_state=self.size_state)
+        result = TaskWindowLayout(
+            position=self.position, size=self.size, size_state=self.size_state
+        )
         for state in self._states:
             if state == self._active_state:
                 result.active_task = state.task.id
@@ -318,8 +332,10 @@ class TaskWindow(ApplicationWindow):
             if state:
                 state.layout = layout
             else:
-                logger.warn("Cannot apply layout for task %r: task does not "
-                            "belong to the window." % layout.id)
+                logger.warn(
+                    "Cannot apply layout for task %r: task does not "
+                    "belong to the window." % layout.id
+                )
 
         # Attempt to activate the requested task.
         state = self._get_state(window_layout.get_active_task())
@@ -331,9 +347,9 @@ class TaskWindow(ApplicationWindow):
             else:
                 self.activate_task(state.task)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'TaskWindow' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _destroy_state(self, state):
         """ Destroy all controls associated with a Task state.
@@ -364,11 +380,15 @@ class TaskWindow(ApplicationWindow):
         if self._active_state:
             layout = self.get_layout()
             panes.append(self.central_pane)
-            for area in ('top', 'right', 'bottom', 'left'):
+            for area in ("top", "right", "bottom", "left"):
                 item = getattr(layout, area)
                 if item:
-                    panes.extend([ self.get_dock_pane(pane_item.id)
-                                   for pane_item in item.iterleaves() ])
+                    panes.extend(
+                        [
+                            self.get_dock_pane(pane_item.id)
+                            for pane_item in item.iterleaves()
+                        ]
+                    )
         return panes
 
     def _get_state(self, id_or_task):
@@ -380,12 +400,12 @@ class TaskWindow(ApplicationWindow):
                 return state
         return None
 
-    #### Trait initializers ###################################################
+    # Trait initializers ---------------------------------------------------
 
     def __window_backend_default(self):
         return TaskWindowBackend(window=self)
 
-    #### Trait property getters/setters #######################################
+    # Trait property getters/setters ---------------------------------------
 
     def _get_title(self):
         if self._title or self.active_task is None:
@@ -395,7 +415,7 @@ class TaskWindow(ApplicationWindow):
     def _set_title(self, title):
         self._title = title
 
-    #### Trait change handlers ################################################
+    # Trait change handlers ------------------------------------------------
 
     def __active_state_changed(self, state):
         if state is None:
@@ -411,14 +431,14 @@ class TaskWindow(ApplicationWindow):
             self.status_bar_manager = state.status_bar_manager
             self.tool_bar_managers = state.tool_bar_managers
 
-    @on_trait_change('central_pane.has_focus, dock_panes.has_focus')
+    @on_trait_change("central_pane.has_focus, dock_panes.has_focus")
     def _focus_updated(self, obj, name, old, new):
-        if name == 'has_focus' and new:
+        if name == "has_focus" and new:
             self.active_pane = obj
 
-    @on_trait_change('_states[]')
+    @on_trait_change("_states[]")
     def _states_updated(self):
-        self.tasks = [ state.task for state in self._states ]
+        self.tasks = [state.task for state in self._states]
 
 
 class TaskState(HasStrictTraits):
