@@ -1,15 +1,23 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 
 import os
 import unittest
 
 from ..image_cache import ImageCache
 
-IMAGE_PATH = os.path.join(os.path.dirname(__file__), 'images', 'core.png')
+IMAGE_PATH = os.path.join(os.path.dirname(__file__), "images", "core.png")
 
 
 class TestPyfaceResourceFactory(unittest.TestCase):
-
     def setUp(self):
         self.image_cache = ImageCache(32, 32)
 
