@@ -1,4 +1,13 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 
 import platform
 import unittest
@@ -8,25 +17,25 @@ from ..constant import OK
 from ..toolkit import toolkit_object
 from ..window import Window
 
-is_qt = toolkit_object.toolkit == 'qt4'
+is_qt = toolkit_object.toolkit == "qt4"
 if is_qt:
     from pyface.qt import qt_api
 
-GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
-no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+GuiTestAssistant = toolkit_object("util.gui_test_assistant:GuiTestAssistant")
+no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 ModalDialogTester = toolkit_object(
-    'util.modal_dialog_tester:ModalDialogTester'
+    "util.modal_dialog_tester:ModalDialogTester"
 )
-no_modal_dialog_tester = (ModalDialogTester.__name__ == 'Unimplemented')
+no_modal_dialog_tester = ModalDialogTester.__name__ == "Unimplemented"
 
-is_pyqt5 = (is_qt and qt_api == 'pyqt5')
-is_pyqt4_linux = (is_qt and qt_api == 'pyqt' and platform.system() == 'Linux')
+is_pyqt5 = is_qt and qt_api == "pyqt5"
+is_pyqt4_linux = is_qt and qt_api == "pyqt" and platform.system() == "Linux"
 
 USING_QT = is_qt
 
 
-@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+@unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
 class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
@@ -134,9 +143,9 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Message dialog click tests don't work reliably on linux.  Issue #282."
+        "Message dialog click tests don't work reliably on linux.  Issue #282.",
     )
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_accept(self):
         # test that accept works as expected
         # XXX duplicate of Dialog test, not needed?
@@ -150,9 +159,9 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Message dialog click tests don't work reliably on linux.  Issue #282."
+        "Message dialog click tests don't work reliably on linux.  Issue #282.",
     )
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_close(self):
         # test that closing works as expected
         # XXX duplicate of Dialog test, not needed?
@@ -166,9 +175,9 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Message dialog click tests don't work reliably on linux.  Issue #282."
+        "Message dialog click tests don't work reliably on linux.  Issue #282.",
     )
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_ok(self):
         # test that OK works as expected
         tester = ModalDialogTester(self.dialog.open)
@@ -177,7 +186,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(self.dialog.return_code, OK)
 
     @unittest.skipIf(USING_QT, "Can't change OK label in Qt")
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_renamed_ok(self):
         self.dialog.ok_label = u"Sure"
         # test that OK works as expected if renamed
@@ -191,9 +200,9 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Message dialog click tests don't work reliably on linux.  Issue #282."
+        "Message dialog click tests don't work reliably on linux.  Issue #282.",
     )
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_parent(self):
         # test that lifecycle works with a parent
         parent = Window()
@@ -209,8 +218,8 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(self.dialog.return_code, OK)
 
 
-@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
-@unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+@unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
+@unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
 class TestMessageDialogHelpers(unittest.TestCase, GuiTestAssistant):
     def test_information(self):
         self._check_dialog(information)
@@ -222,11 +231,11 @@ class TestMessageDialogHelpers(unittest.TestCase, GuiTestAssistant):
         self._check_dialog(error)
 
     def _check_dialog(self, helper):
-        message = 'message'
+        message = "message"
         kwargs = {
-            'title': 'Title',
-            'detail': 'Detail',
-            'informative': 'Informative'
+            "title": "Title",
+            "detail": "Detail",
+            "informative": "Informative",
         }
 
         # smoke test, since dialog helper is opaque
