@@ -1,4 +1,13 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 
 import os
 import sys
@@ -8,15 +17,15 @@ from ..python_shell import PythonShell
 from ..toolkit import toolkit_object
 from ..window import Window
 
-GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
-no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+GuiTestAssistant = toolkit_object("util.gui_test_assistant:GuiTestAssistant")
+no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 PYTHON_SCRIPT = os.path.abspath(
-    os.path.join(os.path.dirname(__file__), 'python_shell_script.py')
+    os.path.join(os.path.dirname(__file__), "python_shell_script.py")
 )
 
 
-@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+@unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
 class TestPythonShell(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
@@ -46,9 +55,9 @@ class TestPythonShell(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget = PythonShell(self.window.control)
         with self.event_loop():
-            self.widget.bind('x', 1)
+            self.widget.bind("x", 1)
 
-        self.assertEqual(self.widget.interpreter().locals.get('x'), 1)
+        self.assertEqual(self.widget.interpreter().locals.get("x"), 1)
 
         with self.event_loop():
             self.widget.destroy()
@@ -58,11 +67,11 @@ class TestPythonShell(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget = PythonShell(self.window.control)
 
-        with self.assertTraitChanges(self.widget, 'command_executed', count=1):
+        with self.assertTraitChanges(self.widget, "command_executed", count=1):
             with self.event_loop():
-                self.widget.execute_command('x = 1')
+                self.widget.execute_command("x = 1")
 
-        self.assertEqual(self.widget.interpreter().locals.get('x'), 1)
+        self.assertEqual(self.widget.interpreter().locals.get("x"), 1)
 
         with self.event_loop():
             self.widget.destroy()
@@ -72,11 +81,11 @@ class TestPythonShell(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget = PythonShell(self.window.control)
 
-        with self.assertTraitChanges(self.widget, 'command_executed', count=1):
+        with self.assertTraitChanges(self.widget, "command_executed", count=1):
             with self.event_loop():
-                self.widget.execute_command('x = 1', hidden=False)
+                self.widget.execute_command("x = 1", hidden=False)
 
-        self.assertEqual(self.widget.interpreter().locals.get('x'), 1)
+        self.assertEqual(self.widget.interpreter().locals.get("x"), 1)
 
         with self.event_loop():
             self.widget.destroy()
@@ -87,12 +96,12 @@ class TestPythonShell(unittest.TestCase, GuiTestAssistant):
             self.widget = PythonShell(self.window.control)
 
         # XXX inconsistent behaviour between backends
-        #with self.assertTraitChanges(self.widget, 'command_executed', count=1):
+        # with self.assertTraitChanges(self.widget, 'command_executed', count=1):
         with self.event_loop():
             self.widget.execute_file(PYTHON_SCRIPT)
 
-        self.assertEqual(self.widget.interpreter().locals.get('x'), 1)
-        self.assertEqual(self.widget.interpreter().locals.get('sys'), sys)
+        self.assertEqual(self.widget.interpreter().locals.get("x"), 1)
+        self.assertEqual(self.widget.interpreter().locals.get("sys"), sys)
 
         with self.event_loop():
             self.widget.destroy()
@@ -103,12 +112,12 @@ class TestPythonShell(unittest.TestCase, GuiTestAssistant):
             self.widget = PythonShell(self.window.control)
 
         # XXX inconsistent behaviour between backends
-        #with self.assertTraitChanges(self.widget, 'command_executed', count=1):
+        # with self.assertTraitChanges(self.widget, 'command_executed', count=1):
         with self.event_loop():
             self.widget.execute_file(PYTHON_SCRIPT, hidden=False)
 
-        self.assertEqual(self.widget.interpreter().locals.get('x'), 1)
-        self.assertEqual(self.widget.interpreter().locals.get('sys'), sys)
+        self.assertEqual(self.widget.interpreter().locals.get("x"), 1)
+        self.assertEqual(self.widget.interpreter().locals.get("sys"), sys)
 
         with self.event_loop():
             self.widget.destroy()
@@ -119,11 +128,11 @@ class TestPythonShell(unittest.TestCase, GuiTestAssistant):
             self.widget = PythonShell(self.window.control)
 
         with self.event_loop():
-            self.widget.execute_command('x = 1', hidden=False)
+            self.widget.execute_command("x = 1", hidden=False)
 
         history, history_index = self.widget.get_history()
 
-        self.assertEqual(history, ['x = 1'])
+        self.assertEqual(history, ["x = 1"])
         self.assertEqual(history_index, 1)
 
         with self.event_loop():
@@ -135,10 +144,10 @@ class TestPythonShell(unittest.TestCase, GuiTestAssistant):
             self.widget = PythonShell(self.window.control)
 
         with self.event_loop():
-            self.widget.set_history(['x = 1', 'y = x + 1'], 1)
+            self.widget.set_history(["x = 1", "y = x + 1"], 1)
 
         history, history_index = self.widget.get_history()
-        self.assertEqual(history, ['x = 1', 'y = x + 1'])
+        self.assertEqual(history, ["x = 1", "y = x + 1"])
         self.assertEqual(history_index, 1)
 
         with self.event_loop():
