@@ -1,4 +1,13 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 
 import unittest
 
@@ -7,11 +16,11 @@ from ..image_resource import ImageResource
 from ..splash_screen import SplashScreen
 from ..toolkit import toolkit_object
 
-GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
-no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+GuiTestAssistant = toolkit_object("util.gui_test_assistant:GuiTestAssistant")
+no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 
-@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+@unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
 class TestWindow(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
@@ -32,12 +41,12 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
     def test_open_close(self):
         # test that opening and closing works as expected
-        with self.assertTraitChanges(self.window, 'opening', count=1):
-            with self.assertTraitChanges(self.window, 'opened', count=1):
+        with self.assertTraitChanges(self.window, "opening", count=1):
+            with self.assertTraitChanges(self.window, "opened", count=1):
                 with self.event_loop():
                     self.window.open()
-        with self.assertTraitChanges(self.window, 'closing', count=1):
-            with self.assertTraitChanges(self.window, 'closed', count=1):
+        with self.assertTraitChanges(self.window, "closing", count=1):
+            with self.assertTraitChanges(self.window, "closed", count=1):
                 with self.event_loop():
                     self.window.close()
 
@@ -54,27 +63,27 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
     def test_image(self):
         # test that images work
-        self.window.image = ImageResource('core')
-        with self.assertTraitChanges(self.window, 'opening', count=1):
-            with self.assertTraitChanges(self.window, 'opened', count=1):
+        self.window.image = ImageResource("core")
+        with self.assertTraitChanges(self.window, "opening", count=1):
+            with self.assertTraitChanges(self.window, "opened", count=1):
                 with self.event_loop():
                     self.window.open()
 
-        with self.assertTraitChanges(self.window, 'closing', count=1):
-            with self.assertTraitChanges(self.window, 'closed', count=1):
+        with self.assertTraitChanges(self.window, "closing", count=1):
+            with self.assertTraitChanges(self.window, "closed", count=1):
                 with self.event_loop():
                     self.window.close()
 
     def test_text(self):
         # test that images work
         self.window.text = "Splash screen"
-        with self.assertTraitChanges(self.window, 'opening', count=1):
-            with self.assertTraitChanges(self.window, 'opened', count=1):
+        with self.assertTraitChanges(self.window, "opening", count=1):
+            with self.assertTraitChanges(self.window, "opened", count=1):
                 with self.event_loop():
                     self.window.open()
 
-        with self.assertTraitChanges(self.window, 'closing', count=1):
-            with self.assertTraitChanges(self.window, 'closed', count=1):
+        with self.assertTraitChanges(self.window, "closing", count=1):
+            with self.assertTraitChanges(self.window, "closed", count=1):
                 with self.event_loop():
                     self.window.close()
 
@@ -82,15 +91,15 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
         # test that images work
         # XXX this throws a non-failing exception on wx
         #     - probably the way the test is written.
-        with self.assertTraitChanges(self.window, 'opening', count=1):
-            with self.assertTraitChanges(self.window, 'opened', count=1):
+        with self.assertTraitChanges(self.window, "opening", count=1):
+            with self.assertTraitChanges(self.window, "opened", count=1):
                 with self.event_loop():
                     self.window.open()
 
         with self.event_loop():
             self.window.text = "Splash screen"
 
-        with self.assertTraitChanges(self.window, 'closing', count=1):
-            with self.assertTraitChanges(self.window, 'closed', count=1):
+        with self.assertTraitChanges(self.window, "closing", count=1):
+            with self.assertTraitChanges(self.window, "closed", count=1):
                 with self.event_loop():
                     self.window.close()
