@@ -1,23 +1,36 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-from traits.testing.unittest_tools import unittest, UnittestTools
+
+import unittest
+
+from traits.testing.unittest_tools import UnittestTools
 
 from ..toolkit import toolkit_object
 from ..widget import Widget
 
-GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
-no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+GuiTestAssistant = toolkit_object("util.gui_test_assistant:GuiTestAssistant")
+no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 
 class ConcreteWidget(Widget):
     def _create_control(self, parent):
-        if toolkit_object.toolkit == 'wx':
+        if toolkit_object.toolkit == "wx":
             import wx
+
             control = wx.Window(parent)
             control.Enable(self.enabled)
             control.Show(self.visible)
-        elif toolkit_object.toolkit == 'qt4':
+        elif toolkit_object.toolkit == "qt4":
             from pyface.qt import QtGui
+
             control = QtGui.QWidget(parent)
             control.setEnabled(self.enabled)
             control.setVisible(self.visible)
@@ -47,31 +60,31 @@ class TestWidget(unittest.TestCase, UnittestTools):
         self.widget.destroy()
 
     def test_show(self):
-        with self.assertTraitChanges(self.widget, 'visible', count=1):
+        with self.assertTraitChanges(self.widget, "visible", count=1):
             self.widget.show(False)
 
         self.assertFalse(self.widget.visible)
 
     def test_visible(self):
-        with self.assertTraitChanges(self.widget, 'visible', count=1):
+        with self.assertTraitChanges(self.widget, "visible", count=1):
             self.widget.visible = False
 
         self.assertFalse(self.widget.visible)
 
     def test_enable(self):
-        with self.assertTraitChanges(self.widget, 'enabled', count=1):
+        with self.assertTraitChanges(self.widget, "enabled", count=1):
             self.widget.enable(False)
 
         self.assertFalse(self.widget.enabled)
 
     def test_enabled(self):
-        with self.assertTraitChanges(self.widget, 'enabled', count=1):
+        with self.assertTraitChanges(self.widget, "enabled", count=1):
             self.widget.enabled = False
 
         self.assertFalse(self.widget.enabled)
 
 
-@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+@unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
 class TestConcreteWidget(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
@@ -103,7 +116,7 @@ class TestConcreteWidget(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget._create()
 
-        with self.assertTraitChanges(self.widget, 'visible', count=1):
+        with self.assertTraitChanges(self.widget, "visible", count=1):
             with self.event_loop():
                 self.widget.show(False)
 
@@ -113,7 +126,7 @@ class TestConcreteWidget(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget._create()
 
-        with self.assertTraitChanges(self.widget, 'visible', count=1):
+        with self.assertTraitChanges(self.widget, "visible", count=1):
             with self.event_loop():
                 self.widget.visible = False
 
@@ -123,7 +136,7 @@ class TestConcreteWidget(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget._create()
 
-        with self.assertTraitChanges(self.widget, 'enabled', count=1):
+        with self.assertTraitChanges(self.widget, "enabled", count=1):
             with self.event_loop():
                 self.widget.enable(False)
 
@@ -133,7 +146,7 @@ class TestConcreteWidget(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget._create()
 
-        with self.assertTraitChanges(self.widget, 'enabled', count=1):
+        with self.assertTraitChanges(self.widget, "enabled", count=1):
             with self.event_loop():
                 self.widget.enabled = False
 
