@@ -1,16 +1,13 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2007, Riverbank Computing Limited
-# All rights reserved.
-#
-# Copyright (c) 2017, Enthought, Inc.
+# (C) Copyright 2007 Riverbank Computing Limited
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license.  However, when used with the GPL version of PyQt the additional
-# terms described in the PyQt GPL exception also apply.
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-# Author: Riverbank Computing Limited and Enthought developers
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 
 import sys
@@ -21,7 +18,7 @@ from pyface.qt import QtCore, QtGui, qt_api
 from pyface.base_toolkit import Toolkit
 from .gui import GUI
 
-if qt_api == 'pyqt':
+if qt_api == "pyqt":
     # Check the version numbers are late enough.
     if QtCore.QT_VERSION < 0x040200:
         raise RuntimeError(
@@ -41,7 +38,7 @@ if _app is None:
 
 
 # create the toolkit object
-toolkit_object = Toolkit('pyface', 'qt4', 'pyface.ui.qt4')
+toolkit_object = Toolkit("pyface", "qt4", "pyface.ui.qt4")
 
 
 # ensure that Traits has a UI handler appropriate for the toolkit.
