@@ -1,13 +1,22 @@
-# Standard library imports.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 import sys
 
-# System library imports.
+
 from pyface.qt import QtCore, QtGui
 
-# Enthought library imports.
+
 from traits.api import DelegatesTo, Instance, on_trait_change, provides
 
-# Local imports.
+
 from pyface.tasks.i_advanced_editor_area_pane import IAdvancedEditorAreaPane
 from pyface.tasks.i_editor_area_pane import MEditorAreaPane
 from .editor_area_pane import EditorAreaDropFilter
@@ -15,9 +24,10 @@ from .main_window_layout import MainWindowLayout, PaneItem
 from .task_pane import TaskPane
 from .util import set_focus
 
-###############################################################################
+# ----------------------------------------------------------------------------
 # 'AdvancedEditorAreaPane' class.
-###############################################################################
+# ----------------------------------------------------------------------------
+
 
 @provides(IAdvancedEditorAreaPane)
 class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
@@ -26,14 +36,13 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
     See the IAdvancedEditorAreaPane interface for API documentation.
     """
 
-
-    #### Private interface ####################################################
+    # Private interface ----------------------------------------------------
 
     _main_window_layout = Instance(MainWindowLayout)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'TaskPane' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def create(self, parent):
         """ Create and set the toolkit-specific control that represents the
@@ -44,19 +53,19 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         self.control.installEventFilter(self._filter)
 
         # Add shortcuts for scrolling through tabs.
-        if sys.platform == 'darwin':
-            next_seq = 'Ctrl+}'
-            prev_seq = 'Ctrl+{'
+        if sys.platform == "darwin":
+            next_seq = "Ctrl+}"
+            prev_seq = "Ctrl+{"
         else:
-            next_seq = 'Ctrl+PgDown'
-            prev_seq = 'Ctrl+PgUp'
+            next_seq = "Ctrl+PgDown"
+            prev_seq = "Ctrl+PgUp"
         shortcut = QtGui.QShortcut(QtGui.QKeySequence(next_seq), self.control)
         shortcut.activated.connect(self._next_tab)
         shortcut = QtGui.QShortcut(QtGui.QKeySequence(prev_seq), self.control)
         shortcut.activated.connect(self._previous_tab)
 
         # Add shortcuts for switching to a specific tab.
-        mod = 'Ctrl+' if sys.platform == 'darwin' else 'Alt+'
+        mod = "Ctrl+" if sys.platform == "darwin" else "Alt+"
         mapper = QtCore.QSignalMapper(self.control)
         mapper.mapped.connect(self._activate_tab)
         for i in range(1, 10):
@@ -78,9 +87,9 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
 
         super(AdvancedEditorAreaPane, self).destroy()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'IEditorAreaPane' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def activate_editor(self, editor):
         """ Activates the specified editor in the pane.
@@ -109,26 +118,28 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         if not self.editors:
             self.active_editor = None
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'IAdvancedEditorAreaPane' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def get_layout(self):
         """ Returns a LayoutItem that reflects the current state of the editors.
         """
         return self._main_window_layout.get_layout_for_area(
-            QtCore.Qt.LeftDockWidgetArea)
+            QtCore.Qt.LeftDockWidgetArea
+        )
 
     def set_layout(self, layout):
         """ Applies a LayoutItem to the editors in the pane.
         """
         if layout is not None:
             self._main_window_layout.set_layout_for_area(
-                layout, QtCore.Qt.LeftDockWidgetArea)
+                layout, QtCore.Qt.LeftDockWidgetArea
+            )
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _activate_tab(self, index):
         """ Activates the tab with the specified index, if there is one.
@@ -160,28 +171,29 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         """
         label = editor.name
         if editor.dirty:
-            label = '*' + label
+            label = "*" + label
         return label
 
-    #### Trait initializers ###################################################
+    # Trait initializers ---------------------------------------------------
 
     def __main_window_layout_default(self):
         return EditorAreaMainWindowLayout(editor_area=self)
 
-    #### Trait change handlers ################################################
+    # Trait change handlers ------------------------------------------------
 
-    @on_trait_change('editors:[dirty, name]')
+    @on_trait_change("editors:[dirty, name]")
     def _update_label(self, editor, name, new):
         editor.control.parent().update_title()
 
-    @on_trait_change('editors:tooltip')
+    @on_trait_change("editors:tooltip")
     def _update_tooltip(self, editor, name, new):
         editor.control.parent().update_tooltip()
 
 
-###############################################################################
+# ----------------------------------------------------------------------------
 # Auxillary classes.
-###############################################################################
+# ----------------------------------------------------------------------------
+
 
 class EditorAreaMainWindowLayout(MainWindowLayout):
     """ A MainWindowLayout for implementing AdvancedEditorAreaPane.
@@ -189,17 +201,17 @@ class EditorAreaMainWindowLayout(MainWindowLayout):
     Used for getting and setting layouts for the pane.
     """
 
-    #### 'MainWindowLayout' interface #########################################
+    # 'MainWindowLayout' interface -----------------------------------------
 
-    control = DelegatesTo('editor_area')
+    control = DelegatesTo("editor_area")
 
-    #### 'TaskWindowLayout' interface #########################################
+    # 'TaskWindowLayout' interface -----------------------------------------
 
     editor_area = Instance(AdvancedEditorAreaPane)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'MainWindowLayout' abstract interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_dock_widget(self, pane):
         """ Returns the QDockWidget associated with a PaneItem.
@@ -223,9 +235,9 @@ class EditorAreaWidget(QtGui.QMainWindow):
     """ An auxillary widget for implementing AdvancedEditorAreaPane.
     """
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'EditorAreaWidget' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __init__(self, editor_area, parent=None):
         super(EditorAreaWidget, self).__init__(parent)
@@ -250,8 +262,9 @@ class EditorAreaWidget(QtGui.QMainWindow):
         self.setDockNestingEnabled(True)
         self.setDocumentMode(True)
         self.setFocusPolicy(QtCore.Qt.StrongFocus)
-        self.setTabPosition(QtCore.Qt.AllDockWidgetAreas,
-                            QtGui.QTabWidget.North)
+        self.setTabPosition(
+            QtCore.Qt.AllDockWidgetAreas, QtGui.QTabWidget.North
+        )
 
     def add_editor_widget(self, editor_widget):
         """ Adds a dock widget to the editor area.
@@ -262,8 +275,10 @@ class EditorAreaWidget(QtGui.QMainWindow):
         # Try to place the editor in a sensible spot.
         top_left = None
         for widget in self.get_dock_widgets():
-            if top_left is None or (widget.pos().manhattanLength() <
-                                    top_left.pos().manhattanLength()):
+            if top_left is None or (
+                widget.pos().manhattanLength()
+                < top_left.pos().manhattanLength()
+            ):
                 top_left = widget
         if top_left:
             self.tabifyDockWidget(top_left, editor_widget)
@@ -283,8 +298,11 @@ class EditorAreaWidget(QtGui.QMainWindow):
     def get_dock_widgets(self):
         """ Gets all visible dock widgets.
         """
-        return [ child for child in self.children()
-                 if isinstance(child, QtGui.QDockWidget) and child.isVisible() ]
+        return [
+            child
+            for child in self.children()
+            if isinstance(child, QtGui.QDockWidget) and child.isVisible()
+        ]
 
     def get_dock_widgets_for_bar(self, tab_bar):
         """ Get the dock widgets, in order, attached to given tab bar.
@@ -304,18 +322,23 @@ class EditorAreaWidget(QtGui.QMainWindow):
     def get_dock_widgets_ordered(self, visible_only=False):
         """ Gets all dock widgets in left-to-right, top-to-bottom order.
         """
-        def compare(one, two):
-            y = cmp(one.pos().y(), two.pos().y())
-            return cmp(one.pos().x(), two.pos().x()) if y == 0 else y
-
         children = []
         for child in self.children():
-            if (child.isWidgetType() and child.isVisible() and
-                ((isinstance(child, QtGui.QTabBar) and not visible_only) or
-                 (isinstance(child, QtGui.QDockWidget) and
-                  (visible_only or not self.tabifiedDockWidgets(child))))):
+            if (
+                child.isWidgetType()
+                and child.isVisible()
+                and (
+                    (isinstance(child, QtGui.QTabBar) and not visible_only)
+                    or (
+                        isinstance(child, QtGui.QDockWidget)
+                        and (
+                            visible_only or not self.tabifiedDockWidgets(child)
+                        )
+                    )
+                )
+            ):
                 children.append(child)
-        children.sort(cmp=compare)
+        children.sort(key=lambda _child: (_child.pos().y(), _child.pos().x()))
 
         widgets = []
         for child in children:
@@ -332,8 +355,11 @@ class EditorAreaWidget(QtGui.QMainWindow):
         tabified = self.tabifiedDockWidgets(editor_widget)
         if tabified:
             widgets = self.get_dock_widgets_ordered()
-            tabified = [widget for widget in widgets \
-                        if widget in tabified or widget == editor_widget]
+            tabified = [
+                widget
+                for widget in widgets
+                if widget in tabified or widget == editor_widget
+            ]
         visible = self.get_dock_widgets_ordered(visible_only=True)
 
         # Destroy and remove the editor. Get the active widget first, since it
@@ -345,9 +371,11 @@ class EditorAreaWidget(QtGui.QMainWindow):
         editor_area = self.editor_area
         choices = tabified if len(tabified) >= 2 else visible
         if len(choices) >= 2 and editor_widget == next_widget:
-             i = choices.index(editor_widget)
-             next_widget = choices[i+1] if i+1 < len(choices) else choices[i-1]
-             editor_area.activate_editor(next_widget.editor)
+            i = choices.index(editor_widget)
+            next_widget = (
+                choices[i + 1] if i + 1 < len(choices) else choices[i - 1]
+            )
+            editor_area.activate_editor(next_widget.editor)
 
         # Update tab bar hide state.
         if len(tabified) == 2:
@@ -383,9 +411,9 @@ class EditorAreaWidget(QtGui.QMainWindow):
             elif len(self.tabifiedDockWidgets(widget)) == 1:
                 widget.set_title_bar(False)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Event handlers.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def childEvent(self, event):
         """ Reimplemented to gain access to the tab bars as they are created.
@@ -396,15 +424,17 @@ class EditorAreaWidget(QtGui.QMainWindow):
             if isinstance(child, QtGui.QTabBar):
                 # Use UniqueConnections since Qt recycles the tab bars.
                 child.installEventFilter(self)
-                child.currentChanged.connect(self._tab_index_changed,
-                                             QtCore.Qt.UniqueConnection)
+                child.currentChanged.connect(
+                    self._tab_index_changed, QtCore.Qt.UniqueConnection
+                )
                 child.setTabsClosable(True)
                 child.setUsesScrollButtons(True)
-                child.tabCloseRequested.connect(self._tab_close_requested,
-                                                QtCore.Qt.UniqueConnection)
+                child.tabCloseRequested.connect(
+                    self._tab_close_requested, QtCore.Qt.UniqueConnection
+                )
                 # FIXME: We would like to have the tabs movable, but this
                 # confuses the QMainWindowLayout. For now, we disable this.
-                #child.setMovable(True)
+                # child.setMovable(True)
 
     def eventFilter(self, obj, event):
         """ Reimplemented to dispatch to sub-handlers.
@@ -427,14 +457,18 @@ class EditorAreaWidget(QtGui.QMainWindow):
             if widget.geometry() == self._rubber_band.geometry():
                 self.set_hover_widget(widget)
 
-        elif self._drag_widget == widget and event.type() == QtCore.QEvent.Move:
+        elif (
+            self._drag_widget == widget and event.type() == QtCore.QEvent.Move
+        ):
             if len(self._tear_widgets) == 1 and not self._tear_handled:
                 widget = self._tear_widgets[0]
                 widget.set_title_bar(True)
                 self._tear_handled = True
 
-        elif self._drag_widget == widget and \
-                 event.type() == QtCore.QEvent.MouseButtonRelease:
+        elif (
+            self._drag_widget == widget
+            and event.type() == QtCore.QEvent.MouseButtonRelease
+        ):
             self.reset_drag()
 
         return False
@@ -442,8 +476,10 @@ class EditorAreaWidget(QtGui.QMainWindow):
     def _filter_rubber_band(self, rubber_band, event):
         """ Support hover widget state tracking.
         """
-        if self._drag_widget and event.type() in (QtCore.QEvent.Resize,
-                                                  QtCore.QEvent.Move):
+        if self._drag_widget and event.type() in (
+            QtCore.QEvent.Resize,
+            QtCore.QEvent.Move,
+        ):
             self.set_hover_widget(None)
 
         return False
@@ -462,15 +498,24 @@ class EditorAreaWidget(QtGui.QMainWindow):
 
                     pos = QtCore.QPoint(0, 0)
                     press_event = QtGui.QMouseEvent(
-                        QtCore.QEvent.MouseButtonPress, pos,
-                        widget.mapToGlobal(pos), QtCore.Qt.LeftButton,
-                        QtCore.Qt.LeftButton, event.modifiers())
+                        QtCore.QEvent.MouseButtonPress,
+                        pos,
+                        widget.mapToGlobal(pos),
+                        QtCore.Qt.LeftButton,
+                        QtCore.Qt.LeftButton,
+                        event.modifiers(),
+                    )
                     QtCore.QCoreApplication.sendEvent(widget, press_event)
                     return True
 
                 event = QtGui.QMouseEvent(
-                        QtCore.QEvent.MouseMove, event.pos(), event.globalPos(),
-                        event.button(), event.buttons(), event.modifiers())
+                    QtCore.QEvent.MouseMove,
+                    event.pos(),
+                    event.globalPos(),
+                    event.button(),
+                    event.buttons(),
+                    event.modifiers(),
+                )
                 QtCore.QCoreApplication.sendEvent(self._drag_widget, event)
                 return True
 
@@ -479,7 +524,7 @@ class EditorAreaWidget(QtGui.QMainWindow):
             # so we provide the tooltips manually.
             widgets = self.get_dock_widgets_for_bar(tab_bar)
             index = tab_bar.tabAt(event.pos())
-            tooltip = widgets[index].editor.tooltip if index >= 0 else ''
+            tooltip = widgets[index].editor.tooltip if index >= 0 else ""
             if tooltip:
                 QtGui.QToolTip.showText(event.globalPos(), tooltip, tab_bar)
             return True
@@ -493,9 +538,9 @@ class EditorAreaWidget(QtGui.QMainWindow):
         if active_editor:
             set_focus(active_editor.control)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Signal handlers.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _focus_changed(self, old, new):
         """ Handle an application-level focus change.
@@ -534,16 +579,20 @@ class EditorWidget(QtGui.QDockWidget):
         self.editor = editor
         self.editor.create(self)
         self.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea)
-        self.setFeatures(QtGui.QDockWidget.DockWidgetClosable |
-                         QtGui.QDockWidget.DockWidgetMovable)
+        self.setFeatures(
+            QtGui.QDockWidget.DockWidgetClosable
+            | QtGui.QDockWidget.DockWidgetMovable
+        )
         self.setWidget(editor.control)
         self.update_title()
 
         # Update the minimum size.
         contents_minsize = editor.control.minimumSize()
         style = self.style()
-        contents_minsize.setHeight(contents_minsize.height()
-            + style.pixelMetric(style.PM_DockWidgetHandleExtent))
+        contents_minsize.setHeight(
+            contents_minsize.height()
+            + style.pixelMetric(style.PM_DockWidgetHandleExtent)
+        )
         self.setMinimumSize(contents_minsize)
 
         self.dockLocationChanged.connect(self.update_title_bar)
@@ -570,8 +619,11 @@ class EditorWidget(QtGui.QDockWidget):
     def set_title_bar(self, title_bar):
         current = self.titleBarWidget()
         editor_area = self.editor.editor_area
-        if title_bar and editor_area and (not editor_area.hide_tab_bar or
-                                          len(editor_area.editors) > 1):
+        if (
+            title_bar
+            and editor_area
+            and (not editor_area.hide_tab_bar or len(editor_area.editors) > 1)
+        ):
             if not isinstance(current, EditorTitleBarWidget):
                 self.setTitleBarWidget(EditorTitleBarWidget(self))
         elif current is None or isinstance(current, EditorTitleBarWidget):
