@@ -1,23 +1,34 @@
-# Standard library imports
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 from contextlib import contextmanager
 
-# Enthought library imports.
+
 from pyface.tasks.i_dock_pane import IDockPane, MDockPane
 from traits.api import Bool, on_trait_change, Property, provides, Tuple
 
-# System library imports.
+
 from pyface.qt import QtCore, QtGui
 
-# Local imports.
+
 from .task_pane import TaskPane
 from .util import set_focus
 
 # Constants.
-AREA_MAP = { 'left'   : QtCore.Qt.LeftDockWidgetArea,
-             'right'  : QtCore.Qt.RightDockWidgetArea,
-             'top'    : QtCore.Qt.TopDockWidgetArea,
-             'bottom' : QtCore.Qt.BottomDockWidgetArea }
-INVERSE_AREA_MAP = dict((int(v), k) for k, v in iter(AREA_MAP.items()))
+AREA_MAP = {
+    "left": QtCore.Qt.LeftDockWidgetArea,
+    "right": QtCore.Qt.RightDockWidgetArea,
+    "top": QtCore.Qt.TopDockWidgetArea,
+    "bottom": QtCore.Qt.BottomDockWidgetArea,
+}
+INVERSE_AREA_MAP = dict((int(v), k) for k, v in AREA_MAP.items())
 
 
 @provides(IDockPane)
@@ -27,17 +38,17 @@ class DockPane(TaskPane, MDockPane):
     See the IDockPane interface for API documentation.
     """
 
-    #### 'IDockPane' interface ################################################
+    # 'IDockPane' interface ------------------------------------------------
 
     size = Property(Tuple)
 
-    #### Protected traits #####################################################
+    # Protected traits -----------------------------------------------------
 
     _receiving = Bool(False)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ITaskPane' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def create(self, parent):
         """ Create and set the dock widget that contains the pane contents.
@@ -47,7 +58,7 @@ class DockPane(TaskPane, MDockPane):
         # Set the widget's object name. This important for QMainWindow state
         # saving. Use the task ID and the pane ID to avoid collisions when a
         # pane is present in multiple tasks attached to the same window.
-        control.setObjectName(self.task.id + ':' + self.id)
+        control.setObjectName(self.task.id + ":" + self.id)
 
         # Configure the dock widget according to the DockPane settings.
         self._set_dock_features()
@@ -68,8 +79,10 @@ class DockPane(TaskPane, MDockPane):
         # of its widgets
         contents_minsize = contents.minimumSize()
         style = control.style()
-        contents_minsize.setHeight(contents_minsize.height()
-            + style.pixelMetric(style.PM_DockWidgetHandleExtent))
+        contents_minsize.setHeight(
+            contents_minsize.height()
+            + style.pixelMetric(style.PM_DockWidgetHandleExtent)
+        )
         control.setMinimumSize(contents_minsize)
 
         # Hide the control by default. Otherwise, the widget will visible in its
@@ -82,18 +95,18 @@ class DockPane(TaskPane, MDockPane):
         if self.control is not None:
             set_focus(self.control.widget())
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'IDockPane' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def create_contents(self, parent):
         """ Create and return the toolkit-specific contents of the dock pane.
         """
         return QtGui.QWidget(parent)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     @contextmanager
     def _signal_context(self):
@@ -105,16 +118,16 @@ class DockPane(TaskPane, MDockPane):
         yield
         self._receiving = original
 
-    #### Trait property getters/setters #######################################
+    # Trait property getters/setters ---------------------------------------
 
     def _get_size(self):
         if self.control is not None:
             return (self.control.width(), self.control.height())
         return (-1, -1)
 
-    #### Trait change handlers ################################################
+    # Trait change handlers ------------------------------------------------
 
-    @on_trait_change('dock_area')
+    @on_trait_change("dock_area")
     def _set_dock_area(self):
         if self.control is not None and not self._receiving:
             # Only attempt to adjust the area if the task is active.
@@ -122,10 +135,11 @@ class DockPane(TaskPane, MDockPane):
             if main_window and self.task == self.task.window.active_task:
                 # Qt will automatically remove the dock widget from its previous
                 # area, if it had one.
-                main_window.addDockWidget(AREA_MAP[self.dock_area],
-                                          self.control)
+                main_window.addDockWidget(
+                    AREA_MAP[self.dock_area], self.control
+                )
 
-    @on_trait_change('closable,floatable,movable')
+    @on_trait_change("closable,floatable,movable")
     def _set_dock_features(self):
         if self.control is not None:
             features = QtGui.QDockWidget.NoDockWidgetFeatures
@@ -137,22 +151,22 @@ class DockPane(TaskPane, MDockPane):
                 features |= QtGui.QDockWidget.DockWidgetMovable
             self.control.setFeatures(features)
 
-    @on_trait_change('name')
+    @on_trait_change("name")
     def _set_dock_title(self):
         if self.control is not None:
             self.control.setWindowTitle(self.name)
 
-    @on_trait_change('floating')
+    @on_trait_change("floating")
     def _set_floating(self):
         if self.control is not None and not self._receiving:
             self.control.setFloating(self.floating)
 
-    @on_trait_change('visible')
+    @on_trait_change("visible")
     def _set_visible(self):
         if self.control is not None and not self._receiving:
             self.control.setVisible(self.visible)
 
-    #### Signal handlers ######################################################
+    # Signal handlers -----------------------------------------------------#
 
     def _receive_dock_area(self, area):
         with self._signal_context():
