@@ -1,3 +1,12 @@
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ Tests for the SplitEditorAreaPane class. """
 
 import os
@@ -5,53 +14,48 @@ import tempfile
 import unittest
 
 from traits.api import HasTraits, Instance
-from traitsui.api import Group, UItem, View
-from traitsui.api import Tabbed as TabbedGroup
 
 from pyface.qt import QtGui, QtCore
-from pyface.tasks.split_editor_area_pane import EditorAreaWidget, \
-    SplitEditorAreaPane
-from pyface.tasks.api import Editor, PaneItem, Splitter, Tabbed, Task, \
-    TaskWindow
+from pyface.tasks.split_editor_area_pane import (
+    EditorAreaWidget,
+    SplitEditorAreaPane,
+)
+from pyface.tasks.api import (
+    Editor,
+    PaneItem,
+    Splitter,
+    Tabbed,
+    Task,
+    TaskWindow,
+)
 from pyface.util.guisupport import get_app_qt4
 from pyface.ui.qt4.util.testing import event_loop
 
 
-class ViewWithTabs(HasTraits):
-    """ A view with tabs used to confuse the SplitEditorAreaPane. """
-    traits_view = View(
-        TabbedGroup(
-            Group(UItem(label='tab 1')),
-            Group(UItem(label='tab 2')),
-        )
-    )
-
-
 class ViewWithTabsEditor(Editor):
-    """ Test editor, displaying a TraitsUI view with tabs. """
+    """ Test editor, displaying a labels in tabs. """
 
-    name = 'Test Editor'
+    name = "Test Editor"
 
     def create(self, parent):
         """ Create and set the toolkit-specific contents of the editor.
         """
-        view = ViewWithTabs()
-        self.ui = view.edit_traits(kind='subpanel', parent=parent)
-        self.control = self.ui.control
+        control = QtGui.QTabWidget()
+        control.addTab(QtGui.QLabel("tab 1"), "group 1")
+        control.addTab(QtGui.QLabel("tab 2"), "group 2")
+        self.control = control
 
     def destroy(self):
         """ Destroy the toolkit-specific control that represents the editor.
         """
         self.control = None
-        self.ui.dispose()
-        self.ui = None
 
 
 class SplitEditorAreaPaneTestTask(Task):
     """ A test task containing a SplitEditorAreaPane. """
 
-    id = 'test_task'
-    name = 'Test Task'
+    id = "test_task"
+    name = "Test Task"
 
     editor_area = Instance(SplitEditorAreaPane, ())
 
@@ -67,13 +71,14 @@ class TestEditorAreaWidget(unittest.TestCase):
 
         parent : parent of the returned root
         """
-        root = EditorAreaWidget(editor_area=SplitEditorAreaPane(),
-                                parent=parent)
-        btn0 = QtGui.QPushButton('0')
-        btn1 = QtGui.QPushButton('1')
+        root = EditorAreaWidget(
+            editor_area=SplitEditorAreaPane(), parent=parent
+        )
+        btn0 = QtGui.QPushButton("0")
+        btn1 = QtGui.QPushButton("1")
         tabwidget = root.tabwidget()
-        tabwidget.addTab(btn0, '0')
-        tabwidget.addTab(btn1, '1')
+        tabwidget.addTab(btn0, "0")
+        tabwidget.addTab(btn1, "1")
         tabwidget.setCurrentIndex(1)
 
         return root
@@ -111,15 +116,18 @@ class TestEditorAreaWidget(unittest.TestCase):
 
         # does the right tabwidget contain nothing but the empty widget?
         self.assertEqual(root.rightchild.tabwidget().count(), 1)
-        self.assertEqual(root.rightchild.tabwidget().widget(0),
-                          root.rightchild.tabwidget().empty_widget)
+        self.assertEqual(
+            root.rightchild.tabwidget().widget(0),
+            root.rightchild.tabwidget().empty_widget,
+        )
 
         # do we have an equally sized split?
         self.assertEqual(root.leftchild.width(), root.rightchild.width())
 
         # is the rightchild active?
-        self.assertEqual(root.editor_area.active_tabwidget,
-                          root.rightchild.tabwidget())
+        self.assertEqual(
+            root.editor_area.active_tabwidget, root.rightchild.tabwidget()
+        )
 
     def _setUp_collapse(self, parent=None):
         """ Creates a root, its leftchild and rightchild, so that collapse can
@@ -131,20 +139,20 @@ class TestEditorAreaWidget(unittest.TestCase):
         """
         # setup leftchild
         left = EditorAreaWidget(editor_area=SplitEditorAreaPane(), parent=None)
-        btn0 = QtGui.QPushButton('btn0')
-        btn1 = QtGui.QPushButton('btn1')
+        btn0 = QtGui.QPushButton("btn0")
+        btn1 = QtGui.QPushButton("btn1")
         tabwidget = left.tabwidget()
-        tabwidget.addTab(btn0, '0')
-        tabwidget.addTab(btn1, '1')
+        tabwidget.addTab(btn0, "0")
+        tabwidget.addTab(btn1, "1")
         tabwidget.setCurrentIndex(1)
 
         # setup rightchild
         right = EditorAreaWidget(editor_area=left.editor_area, parent=None)
-        btn2 = QtGui.QPushButton('btn2')
-        btn3 = QtGui.QPushButton('btn3')
+        btn2 = QtGui.QPushButton("btn2")
+        btn3 = QtGui.QPushButton("btn3")
         tabwidget = right.tabwidget()
-        tabwidget.addTab(btn2, '2')
-        tabwidget.addTab(btn3, '3')
+        tabwidget.addTab(btn2, "2")
+        tabwidget.addTab(btn3, "3")
         tabwidget.setCurrentIndex(0)
 
         # setup root
@@ -212,8 +220,9 @@ class TestEditorAreaWidget(unittest.TestCase):
         self.assertEqual(root.rightchild.tabwidget().currentIndex(), 0)
 
         # what is the current active_tabwidget?
-        self.assertEqual(root.editor_area.active_tabwidget,
-                          root.leftchild.tabwidget())
+        self.assertEqual(
+            root.editor_area.active_tabwidget, root.leftchild.tabwidget()
+        )
 
     def test_persistence(self):
         """ Tests whether get_layout/set_layout work correctly by setting a
@@ -223,21 +232,24 @@ class TestEditorAreaWidget(unittest.TestCase):
         # on the rightchild of horizontal split, where the top tabwidget of
         # the vertical split is empty.
         layout = Splitter(
-            Tabbed(PaneItem(id=0, width=600, height=600),
-                   active_tab=0),
-            Splitter(Tabbed(PaneItem(id=-1, width=600, height=300),
-                            active_tab=0),
-                     Tabbed(PaneItem(id=1, width=600, height=300),
-                            PaneItem(id=2, width=600, height=300),
-                            active_tab=0),
-                     orientation='vertical'),
-            orientation='horizontal')
+            Tabbed(PaneItem(id=0, width=600, height=600), active_tab=0),
+            Splitter(
+                Tabbed(PaneItem(id=-1, width=600, height=300), active_tab=0),
+                Tabbed(
+                    PaneItem(id=1, width=600, height=300),
+                    PaneItem(id=2, width=600, height=300),
+                    active_tab=0,
+                ),
+                orientation="vertical",
+            ),
+            orientation="horizontal",
+        )
         # a total of 3 files are needed to give this layout - one on the
         # leftchild of horizontal split, and the other two on the bottom
         # tabwidget of the rightchild's vertical split
-        file0 = open(os.path.join(tempfile.gettempdir(), 'file0'), 'w+b')
-        file1 = open(os.path.join(tempfile.gettempdir(), 'file1'), 'w+b')
-        file2 = open(os.path.join(tempfile.gettempdir(), 'file2'), 'w+b')
+        file0 = open(os.path.join(tempfile.gettempdir(), "file0"), "w+b")
+        file1 = open(os.path.join(tempfile.gettempdir(), "file1"), "w+b")
+        file2 = open(os.path.join(tempfile.gettempdir(), "file2"), "w+b")
 
         # adding the editors
         editor_area = SplitEditorAreaPane()
@@ -246,16 +258,19 @@ class TestEditorAreaWidget(unittest.TestCase):
         editor_area.add_editor(Editor(obj=file1, tooltip="test_tooltip1"))
         editor_area.add_editor(Editor(obj=file2, tooltip="test_tooltip2"))
 
-        ######## test tooltips #############
+        # test tooltips
 
-        self.assertEqual(editor_area.active_tabwidget.tabToolTip(0),
-                          "test_tooltip0")
-        self.assertEqual(editor_area.active_tabwidget.tabToolTip(1),
-                          "test_tooltip1")
-        self.assertEqual(editor_area.active_tabwidget.tabToolTip(2),
-                          "test_tooltip2")
+        self.assertEqual(
+            editor_area.active_tabwidget.tabToolTip(0), "test_tooltip0"
+        )
+        self.assertEqual(
+            editor_area.active_tabwidget.tabToolTip(1), "test_tooltip1"
+        )
+        self.assertEqual(
+            editor_area.active_tabwidget.tabToolTip(2), "test_tooltip2"
+        )
 
-        ######## test set_layout #############
+        # test set_layout
 
         # set the layout
         editor_area.set_layout(layout)
@@ -291,14 +306,14 @@ class TestEditorAreaWidget(unittest.TestCase):
         # file1 tab is active?
         self.assertEqual(right_bottom.tabwidget().currentIndex(), 0)
 
-        ######### test get_layout #############
+        # test get_layout
 
         # obtain layout
         layout_new = editor_area.get_layout()
 
         # is the top level a horizontal splitter?
         self.assertIsInstance(layout_new, Splitter)
-        self.assertEqual(layout_new.orientation, 'horizontal')
+        self.assertEqual(layout_new.orientation, "horizontal")
 
         # tests on left child
         left = layout_new.items[0]
@@ -308,7 +323,7 @@ class TestEditorAreaWidget(unittest.TestCase):
         # tests on right child
         right = layout_new.items[1]
         self.assertIsInstance(right, Splitter)
-        self.assertEqual(right.orientation, 'vertical')
+        self.assertEqual(right.orientation, "vertical")
 
         # tests on top pane of right child
         right_top = right.items[0]
@@ -321,6 +336,113 @@ class TestEditorAreaWidget(unittest.TestCase):
         self.assertEqual(right_bottom.items[0].id, 1)
         self.assertEqual(right_bottom.items[1].id, 2)
 
+    def test_context_menu_merge_text_left_right_split(self):
+        # Regression test for enthought/pyface#422
+        window = TaskWindow()
+
+        task = SplitEditorAreaPaneTestTask()
+        editor_area = task.editor_area
+        window.add_task(task)
+
+        with event_loop():
+            window.open()
+
+        editor_area_widget = editor_area.control
+        with event_loop():
+            editor_area_widget.split(orientation=QtCore.Qt.Horizontal)
+
+        # Get the tabs.
+        left_tab, right_tab = editor_area_widget.tabwidgets()
+
+        # Check left context menu merge text.
+        left_tab_center = left_tab.mapToGlobal(left_tab.rect().center())
+        left_context_menu = editor_area.get_context_menu(left_tab_center)
+        self.assertEqual(
+            left_context_menu.find_item("merge").action.name,
+            "Merge with right pane",
+        )
+
+        # And the right context menu merge text.
+        right_tab_center = right_tab.mapToGlobal(right_tab.rect().center())
+        right_context_menu = editor_area.get_context_menu(right_tab_center)
+        self.assertEqual(
+            right_context_menu.find_item("merge").action.name,
+            "Merge with left pane",
+        )
+
+        with event_loop():
+            window.close()
+
+    def test_context_menu_merge_text_top_bottom_split(self):
+        # Regression test for enthought/pyface#422
+        window = TaskWindow()
+
+        task = SplitEditorAreaPaneTestTask()
+        editor_area = task.editor_area
+        window.add_task(task)
+
+        with event_loop():
+            window.open()
+
+        editor_area_widget = editor_area.control
+        with event_loop():
+            editor_area_widget.split(orientation=QtCore.Qt.Vertical)
+
+        # Get the tabs.
+        top_tab, bottom_tab = editor_area_widget.tabwidgets()
+
+        # Check top context menu merge text.
+        top_tab_center = top_tab.mapToGlobal(top_tab.rect().center())
+        top_context_menu = editor_area.get_context_menu(top_tab_center)
+        self.assertEqual(
+            top_context_menu.find_item("merge").action.name,
+            "Merge with bottom pane",
+        )
+
+        # And the bottom context menu merge text.
+        bottom_tab_center = bottom_tab.mapToGlobal(bottom_tab.rect().center())
+        bottom_context_menu = editor_area.get_context_menu(bottom_tab_center)
+        self.assertEqual(
+            bottom_context_menu.find_item("merge").action.name,
+            "Merge with top pane",
+        )
+
+        with event_loop():
+            window.close()
+
+    def test_no_context_menu_if_outside_tabwidgets(self):
+        # Check that the case of a position not in any of the tab widgets
+        # is handled correctly.
+        window = TaskWindow()
+
+        task = SplitEditorAreaPaneTestTask()
+        window.add_task(task)
+
+        with event_loop():
+            window.open()
+
+        editor_area = task.editor_area
+        editor_area_widget = editor_area.control
+        tab_widget, = editor_area_widget.tabwidgets()
+
+        # Position is relative to the receiving widget, so (-1, -1) should be
+        # reliably outside.
+        pos = QtCore.QPoint(-1, -1)
+        context_menu_event = QtGui.QContextMenuEvent(
+            QtGui.QContextMenuEvent.Mouse, pos
+        )
+
+        global_pos = editor_area_widget.mapToGlobal(pos)
+        self.assertIsNone(editor_area.get_context_menu(global_pos))
+
+        # Exercise the context menu code to make sure it doesn't raise. (It
+        # should do nothing.)
+        with event_loop():
+            tab_widget.contextMenuEvent(context_menu_event)
+
+        with event_loop():
+            window.close()
+
     def test_active_tabwidget_after_editor_containing_tabs_gets_focus(self):
         # Regression test: if an editor contains tabs, a change in focus
         # sets the editor area pane `active_tabwidget` to one of those tabs,
@@ -349,8 +471,9 @@ class TestEditorAreaWidget(unittest.TestCase):
             editor_area.activate_editor(editor)
 
         # Check that the active tabwidget is the right one.
-        self.assertIs(editor_area.active_tabwidget,
-                      editor_area.control.tabwidget())
+        self.assertIs(
+            editor_area.active_tabwidget, editor_area.control.tabwidget()
+        )
 
         with event_loop():
             window.close()
@@ -393,5 +516,6 @@ class TestEditorAreaWidget(unittest.TestCase):
         with event_loop():
             window.close()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest.main()
