@@ -1,10 +1,11 @@
-# (C) Copyright 2014-2017 Enthought, Inc., Austin, TX
-# All right reserved.
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A class to facilitate testing components that use TraitsUI or Qt Dialogs.
 
@@ -22,12 +23,7 @@ from .event_loop_helper import EventLoopHelper
 from .testing import find_qt_widget
 
 
-BUTTON_TEXT = {
-    OK: 'OK',
-    CANCEL: 'Cancel',
-    YES: 'Yes',
-    NO: 'No',
-}
+BUTTON_TEXT = {OK: u"OK", CANCEL: u"Cancel", YES: u"Yes", NO: u"No"}
 
 
 class ModalDialogTester(object):
@@ -58,6 +54,7 @@ class ModalDialogTester(object):
          manager is used from the GuiTestAssistant when necessary.
 
     """
+
     def __init__(self, function):
         #: The command to call that will cause a dialog to open.
         self.function = function
@@ -133,7 +130,8 @@ class ModalDialogTester(object):
             self._gui.invoke_later(self.open, *args, **kwargs)
             # wait in the event loop until timeout or a return value assigned.
             self._helper.event_loop_until_condition(
-                condition=self.value_assigned, timeout=15)
+                condition=self.value_assigned, timeout=15
+            )
         finally:
             condition_timer.stop()
             condition_timer.timeout.disconnect(handler)
@@ -181,7 +179,7 @@ class ModalDialogTester(object):
             if self._dialog_widget is None:
                 return False
             else:
-                value = (self.get_dialog_widget() != self._dialog_widget)
+                value = self.get_dialog_widget() != self._dialog_widget
                 if value:
                     # process any pending events so that we have a clean
                     # event loop before we exit.
@@ -200,7 +198,8 @@ class ModalDialogTester(object):
             self._gui.invoke_later(self.open, *args, **kwargs)
             # wait in the event loop until timeout or a return value assigned.
             self._helper.event_loop_until_condition(
-                condition=condition, timeout=15)
+                condition=condition, timeout=15
+            )
         finally:
             condition_timer.stop()
             condition_timer.timeout.disconnect(handler)
@@ -257,14 +256,14 @@ class ModalDialogTester(object):
 
         """
         if len(self._event_loop_error) > 0:
-            msg = 'The following error(s) were detected:\n\n{0}'
+            msg = "The following error(s) were detected:\n\n{0}"
             tracebacks = []
             for type_, message in self._event_loop_error:
                 if isinstance(type_, AssertionError):
-                    msg = 'The following failure(s) were detected:\n\n{0}'
+                    msg = "The following failure(s) were detected:\n\n{0}"
                 tracebacks.append(message)
 
-            raise type_(msg.format('\n\n'.join(tracebacks)))
+            raise type_(msg.format("\n\n".join(tracebacks)))
 
     def click_widget(self, text, type_=QtGui.QPushButton):
         """ Execute click on the widget of `type_` with `text`.
@@ -278,13 +277,9 @@ class ModalDialogTester(object):
             # XXX asking for widget.text() causes occasional segfaults on Linux
             # and pyqt (both 4 and 5).  Not sure why this is happening.
             # See issue #282
-            return widget.text().replace('&', '') == text
+            return widget.text().replace("&", "") == text
 
-        widget = find_qt_widget(
-            control,
-            type_,
-            test=test
-        )
+        widget = find_qt_widget(control, type_, test=test)
         if widget is None:
             # this will only occur if there is some problem with the test
             raise RuntimeError("Could not find matching child widget.")
@@ -312,7 +307,7 @@ class ModalDialogTester(object):
         dialog = self.get_dialog_widget()
         if dialog is None:
             return False
-        if hasattr(dialog, '_ui'):
+        if hasattr(dialog, "_ui"):
             # This is a traitsui dialog, we need one more check.
             ui = dialog._ui
             return ui.info.initialized
