@@ -1,17 +1,18 @@
-# Copyright (c) 2013-2015 by Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
 """ Tests for the tabular editor tester. """
-from __future__ import absolute_import
+
 
 import unittest
-from six.moves import cStringIO as StringIO
+from io import StringIO
 import platform
 
 from pyface.qt import QtGui
@@ -25,39 +26,41 @@ from pyface.ui.qt4.util.modal_dialog_tester import ModalDialogTester
 from pyface.util.testing import skip_if_no_traitsui
 
 
-is_qt = toolkit_object.toolkit == 'qt4'
+is_qt = toolkit_object.toolkit == "qt4"
 if is_qt:
     from pyface.qt import qt_api
-is_pyqt5 = (is_qt and qt_api == 'pyqt5')
+is_pyqt5 = is_qt and qt_api == "pyqt5"
 
 
 class MyClass(HasStrictTraits):
-
     def default_traits_view(self):
         from traitsui.api import CancelButton, OKButton, View
 
         view = View(
             buttons=[OKButton, CancelButton],
             resizable=False,
-            title='My class dialog')
+            title="My class dialog",
+        )
         return view
 
     def run(self):
-        ui = self.edit_traits(kind='livemodal')
+        ui = self.edit_traits(kind="livemodal")
         if ui.result:
-            return 'accepted'
+            return "accepted"
         else:
-            return 'rejected'
+            return "rejected"
 
     def do_not_show_dialog(self):
         return True
 
 
-@unittest.skipIf(is_pyqt5, "ModalDialogTester not working on pyqt5. Issue #302")
+@unittest.skipIf(
+    is_pyqt5, "ModalDialogTester not working on pyqt5. Issue #302"
+)
 class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
     """ Tests for the modal dialog tester. """
 
-    #### Tests ################################################################
+    # Tests ----------------------------------------------------------------
 
     def test_on_message_dialog(self):
         dialog = MessageDialog()
@@ -83,13 +86,13 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
         # accept
         tester.open_and_run(when_opened=lambda x: x.close(accept=True))
         self.assertTrue(tester.value_assigned())
-        self.assertEqual(tester.result, 'accepted')
+        self.assertEqual(tester.result, "accepted")
         self.assertTrue(tester.dialog_was_opened)
 
         # reject
         tester.open_and_run(when_opened=lambda x: x.close())
         self.assertTrue(tester.value_assigned())
-        self.assertEqual(tester.result, 'rejected')
+        self.assertEqual(tester.result, "rejected")
         self.assertTrue(tester.dialog_was_opened)
 
     @skip_if_no_traitsui
@@ -122,7 +125,7 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
             alt_stderr = StringIO
             with silence_output(err=alt_stderr):
                 tester.open_and_run(when_opened=failure)
-            self.assertIn('raise self.failureException(msg)', alt_stderr)
+            self.assertIn("raise self.failureException(msg)", alt_stderr)
 
     def test_capture_errors_on_error(self):
         dialog = MessageDialog()
@@ -141,7 +144,7 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
             alt_stderr = StringIO
             with silence_output(err=alt_stderr):
                 tester.open_and_run(when_opened=raise_error)
-            self.assertIn('ZeroDivisionError', alt_stderr)
+            self.assertIn("ZeroDivisionError", alt_stderr)
 
     @unittest.skip("has_widget code not working as designed. Issue #282.")
     def test_has_widget(self):
@@ -152,10 +155,10 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
             try:
                 with tester.capture_error():
                     self.assertTrue(
-                        tester.has_widget('OK', QtGui.QAbstractButton)
+                        tester.has_widget("OK", QtGui.QAbstractButton)
                     )
                     self.assertFalse(
-                        tester.has_widget(text='I am a virtual button')
+                        tester.has_widget(text="I am a virtual button")
                     )
             finally:
                 tester.close()
@@ -172,7 +175,7 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
                 with tester.capture_error():
                     widget = tester.find_qt_widget(
                         type_=QtGui.QAbstractButton,
-                        test=lambda x: x.text() == 'OK'
+                        test=lambda x: x.text() == "OK",
                     )
                     self.assertIsInstance(widget, QtGui.QPushButton)
             finally:
@@ -181,5 +184,5 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
         tester.open_and_run(when_opened=check_and_close)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
