@@ -1,11 +1,20 @@
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 import mock
-
-from traits.testing.unittest_tools import unittest
+import unittest
 
 from pyface.ui.qt4.workbench.split_tab_widget import SplitTabWidget
-from pyface.ui.qt4.workbench.workbench_window_layout import \
-    WorkbenchWindowLayout
+from pyface.ui.qt4.workbench.workbench_window_layout import (
+    WorkbenchWindowLayout,
+)
 
 
 class TestWorkbenchWindowLayout(unittest.TestCase):
