@@ -1,29 +1,24 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought, Inc.
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
 """ Enthought pyface package component
 """
 
-# Major package imports.
+
 import wx
 
-# Enthought library imports.
-from traits.api import Instance, Int, provides, Unicode
 
-# Local imports.
+from traits.api import Instance, Int, provides, Str
+
+
 from pyface.i_heading_text import IHeadingText, MHeadingText
 from pyface.image_resource import ImageResource
 from pyface.wx.util.font_helper import new_font_like
@@ -36,18 +31,17 @@ class HeadingText(MHeadingText, Widget):
     IHeadingText interface for the API documentation.
     """
 
-
-    #### 'IHeadingText' interface #############################################
+    # 'IHeadingText' interface ---------------------------------------------
 
     level = Int(1)
 
-    text = Unicode('Default')
+    text = Str("Default")
 
-    image = Instance(ImageResource, ImageResource('heading_level_1'))
+    image = Instance(ImageResource, ImageResource("heading_level_1"))
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'object' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __init__(self, parent, **traits):
         """ Creates the panel. """
@@ -60,9 +54,9 @@ class HeadingText(MHeadingText, Widget):
 
         return
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_control(self, parent):
         """ Create the toolkit-specific control that represents the widget. """
@@ -82,8 +76,8 @@ class HeadingText(MHeadingText, Widget):
         width, height = self._get_preferred_size(self.text, self._font)
         panel.SetMinSize((width, height))
 
-        wx.EVT_PAINT(panel, self._on_paint_background)
-        wx.EVT_ERASE_BACKGROUND(panel, self._on_erase_background)
+        panel.Bind(wx.EVT_PAINT, self._on_paint_background)
+        panel.Bind(wx.EVT_ERASE_BACKGROUND, self._on_erase_background)
 
         return panel
 
@@ -114,7 +108,7 @@ class HeadingText(MHeadingText, Widget):
 
         return
 
-    #### Trait event handlers #################################################
+    # Trait event handlers -------------------------------------------------
 
     def _text_changed(self, new):
         """ Called when the text is changed. """
@@ -124,7 +118,7 @@ class HeadingText(MHeadingText, Widget):
 
         return
 
-    #### wx event handlers ####################################################
+    # wx event handlers ----------------------------------------------------
 
     def _on_paint_background(self, event):
         """ Called when the background of the panel is painted. """
@@ -139,8 +133,6 @@ class HeadingText(MHeadingText, Widget):
         dc.SetFont(self._font)
         dc.DrawText(self.text, 5, 4)
 
-        return
-
     def _on_erase_background(self, event):
         """ Called when the background of the panel is erased. """
 
@@ -155,5 +147,3 @@ class HeadingText(MHeadingText, Widget):
         dc.DrawText(self.text, 5, 4)
 
         return
-
-#### EOF ######################################################################
